import { Album, Gallery, Image, ImageVariant } from "@/generated/prisma";
import NextImage from "next/image";
import Link from "next/link";

type Props = {
  image: Image & {
    variants: ImageVariant[];
    album: Album & { gallery: Gallery | null } | null;
  };
  showNSFW?: boolean;
};

export default function ImageCard({ image, showNSFW = false }: Props) {
  const variant = image.variants.find(v => v.type === "thumbnail") || image.variants[0];
  if (!variant) return null;

  const href = image.album?.gallery && image.album
    ? `/galleries/${image.album.gallery.slug}/${image.album.slug}/${image.id}`
    : `/image/${image.id}`;

  const shouldBlur = image.nsfw && !showNSFW;

  return (
    <Link href={href} className="group relative overflow-hidden rounded-lg border bg-background shadow transition hover:shadow-lg">
      <div className="aspect-[4/5] w-full relative">
        <NextImage
          src={`/api/image/${variant.s3Key}`}
          alt={image.altText || image.imageName}
          width={variant.width}
          height={variant.height}
          className={`object-cover h-full transition duration-200 ease-in-out ${shouldBlur ? "blur-md scale-105" : ""
            }`}
        />
        {image.nsfw && (
          <div className="absolute top-1 left-1 bg-black/60 text-white text-xs px-2 py-0.5 rounded z-10">
            NSFW
          </div>
        )}
        <div className="absolute bottom-0 left-0 w-full bg-black/50 text-white text-sm px-2 py-1 line-clamp-1 truncate">
          {image.imageName}
        </div>
      </div>
    </Link>
  );
}
